/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.databinding;

import static org.eclipse.core.databinding.validation.ValidationStatus.cancel;
import static org.eclipse.core.databinding.validation.ValidationStatus.ok;

import java.text.NumberFormat;
import java.text.ParsePosition;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.runtime.IStatus;

/** Validates if a given input is a valid {@link Number}. */
public class NumberValidator implements IValidator {

	/** Singleton instance. */
	public static final NumberValidator NUMBER_VALIDATOR = new NumberValidator();

	/** The number format used in the current locale. */
	private final NumberFormat format;

	/** Constructor. */
	protected NumberValidator() {
		format = NumberFormat.getNumberInstance();
		format.setGroupingUsed(false);
	}

	/** {@inheritDoc} */
	@Override
	public IStatus validate(Object value) {
		String input = value != null ? value.toString().trim() : "";
		if(input.isEmpty()) {
			return ok();
		}

		ParsePosition p = new ParsePosition(0);
		format.parse(input, p);
		int errorIndex = p.getErrorIndex();
		// In case the input as a valid prefix, the error index will not indicate a problem.
		// Therefore, check if the entire input was parsed.
		if(errorIndex == -1 && p.getIndex() < input.length()) {
			errorIndex = p.getIndex();
		}

		return errorIndex == -1 ? ok()
				: cancel("Double number format validation failed at position " + errorIndex + ".");
	}
}
