/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.dialog;

import org.eclipse.jface.dialogs.PopupDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

import org.conqat.lib.commons.string.StringUtils;

/**
 * A special popup dialog that can be shown adjacent to another shell to show
 * additional information. This class is based on the inner and internal class
 * <code>InfoPopupDialog</code> of class
 * {@link org.eclipse.jface.fieldassist.ContentProposalAdapter}.
 * 
 * @author deissenb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 0023F672F3D4E77E61AD014A2F4DF25E
 */
public class InfoPopupDialog extends PopupDialog {

	/** The text control that displays the text. */
	private Text text;

	/** The text shown in the popup. */
	private String contents = StringUtils.EMPTY_STRING;

	/**
	 * Construct a new info popup.
	 * 
	 * @param otherShell
	 *            the shell this popup should appear adjacent to.
	 */
	public InfoPopupDialog(Shell otherShell) {
		super(otherShell, PopupDialog.HOVER_SHELLSTYLE, false, false, false,
				false, false, null, null);

	}

	/** {@inheritDoc} */
	@Override
	protected Control createDialogArea(Composite parent) {
		text = new Text(parent, SWT.MULTI | SWT.READ_ONLY | SWT.WRAP
				| SWT.NO_FOCUS);
		GridData data = new GridData(GridData.BEGINNING | GridData.FILL_BOTH);
		data.horizontalIndent = PopupDialog.POPUP_HORIZONTALSPACING;
		data.verticalIndent = PopupDialog.POPUP_VERTICALSPACING;
		text.setLayoutData(data);
		text.setText(contents);
		return text;
	}

	/**
	 * Adjust the bounds so that popup appear adjacent to our parent shell
	 */
	@Override
	protected void adjustBounds() {
		Rectangle parentBounds = getParentShell().getBounds();
		Rectangle proposedBounds;
		// Try placing the info popup to the right
		Rectangle rightProposedBounds = new Rectangle(parentBounds.x
				+ parentBounds.width + PopupDialog.POPUP_HORIZONTALSPACING,
				parentBounds.y, parentBounds.width * 2, parentBounds.height);
		rightProposedBounds = getConstrainedShellBounds(rightProposedBounds);
		// If it won't fit on the right, try the left
		if (rightProposedBounds.intersects(parentBounds)) {
			Rectangle leftProposedBounds = new Rectangle(parentBounds.x
					- parentBounds.width * 2 - POPUP_HORIZONTALSPACING - 1,
					parentBounds.y, parentBounds.width * 2, parentBounds.height);
			leftProposedBounds = getConstrainedShellBounds(leftProposedBounds);
			// If it won't fit on the left, choose the proposed bounds
			// that fits the best
			if (leftProposedBounds.intersects(parentBounds)) {
				if (rightProposedBounds.x - parentBounds.x >= parentBounds.x
						- leftProposedBounds.x) {
					rightProposedBounds.x = parentBounds.x + parentBounds.width
							+ PopupDialog.POPUP_HORIZONTALSPACING;
					proposedBounds = rightProposedBounds;
				} else {
					leftProposedBounds.width = parentBounds.x
							- POPUP_HORIZONTALSPACING - leftProposedBounds.x;
					proposedBounds = leftProposedBounds;
				}
			} else {
				// use the proposed bounds on the left
				proposedBounds = leftProposedBounds;
			}
		} else {
			// use the proposed bounds on the right
			proposedBounds = rightProposedBounds;
		}
		getShell().setBounds(proposedBounds);
	}

	/**
	 * Set the text contents of the popup. If the contents are <code>null</code>
	 * , empty text is shown.
	 */
	public void setContents(String contents) {
		if (contents == null) {
			contents = StringUtils.EMPTY_STRING;
		}
		this.contents = contents;
		if (text != null && !text.isDisposed()) {
			text.setText(contents);
		}
	}

}